@@ -62,7 +62,6 @@ QString Controller::getLanguage() {
     QSqlQuery query("select value from settings where setting = 'language'");
     QSqlRecord record = query.record();
     QString language;
-
     if (record.count() > 0) {
         while (query.next()) {
             language = query.value(0).toString();
@@ -74,6 +73,25 @@ QString Controller::getLanguage() {
     return langCode;
 }
 
+QStringList Controller::getDefaultAccountFromDB() {
+    QSqlDatabase db;
+    db = QSqlDatabase::addDatabase("QSQLITE");
+    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
+    db.open();
+
+    QSqlQuery query("select username, password from accounts where isDefault = '1'");
+    QSqlRecord record = query.record();
+    QStringList account;
+    if (record.count() > 0) {
+        while (query.next()) {
+            account << query.value(0).toString();
+            account << query.value(1).toString();
+        }
+//        qDebug() << account;
+    }
+    return account;
+}
+
 void Controller::setOrientation(const QString &orient) {
     if (orient == "Automatic") {
         m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
@@ -108,7 +126,6 @@ void Controller::getMediaPlayerFromDB() {
     QSqlQuery query("select value from settings where setting = 'mediaPlayer'");
     QSqlRecord record = query.record();
     QString player = "Media Player";
-
     if (record.count() > 0) {
         while (query.next()) {
             player = query.value(0).toString();
