@@ -3,6 +3,7 @@
 
 #include <QObject>
 #include <QProcess>
+#include <QSqlRecord>
 
 class QWidget;
 
@@ -24,6 +25,7 @@ public slots:
     bool xTubeInstalled();
     void setMediaPlayer(const QString &player);
     void getMediaPlayerFromDB();
+    QStringList getDefaultAccountFromDB();
     void toggleState();
     void minimize();
     void playVideo(const QString &url);
