@@ -40,7 +40,7 @@ int main(int argc, char *argv[])
 
         qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
-    #ifdef Q_WS_MAEMO_5
+#ifdef Q_WS_MAEMO_5
         //    viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
         //    viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
         viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
@@ -62,18 +62,36 @@ int main(int argc, char *argv[])
         if (translator.load("/opt/usr/share/qmltube/qml/qmltube/i18n/qml_" + locale)) {
             app.installTranslator(&translator);
         }
-    #endif
+#endif
 
         viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
         viewer.showFullScreen();
 
         return app.exec();
     }
+    else if (args.first() == ("--login")) {
+        /* Print accessToken to stdout for use by the widget*/
 
-    else {
+        QNetworkAccessManager *manager = new QNetworkAccessManager();
+        yt.setNetworkAccessManager(manager);
+
+        QStringList account = ct.getDefaultAccountFromDB();
+        if (account.length() == 0) {
+            return 0;
+        }
+        QString username = account.first();
+        QString password = account.last();
+        QObject::connect(&yt, SIGNAL(accessTokenChanged()), &yt, SLOT(printAccessToken()));
+        QObject::connect(&yt, SIGNAL(tokenPrinted()), &app, SLOT(quit()));
+        yt.login(username, password);
+
+        app.exec();
+
+    }
+    else if (args.first() == ("--play")) {
         /* Get the video URL and play the video */
 
-        QString playerUrl = args.at(0);
+        QString playerUrl = args.last();
         ct.getMediaPlayerFromDB();
         QObject::connect(&yt, SIGNAL(gotVideoUrl(QString)), &ct, SLOT(playVideo(QString)));
         QObject::connect(&yt, SIGNAL(videoUrlError()), &app, SLOT(quit()));
@@ -82,4 +100,7 @@ int main(int argc, char *argv[])
 
         app.exec();
     }
+    else {
+        return 0;
+    }
 }
