@@ -4,9 +4,13 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.5.1</source>
-        <translation>cuteTube-QML - 0.5.1 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.5.1 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.6.1</source>
+        <translation>cuteTube-QML - 0.6.1 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -187,22 +191,22 @@
         <translation>Suomi</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="131"/>
+        <location filename="../../../controller.cpp" line="168"/>
         <source>Video deleted from device</source>
         <translation>Video poistettu laitteesta</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="134"/>
+        <location filename="../../../controller.cpp" line="171"/>
         <source>Unable to delete video</source>
         <translation>Videon poisto epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="138"/>
+        <location filename="../../../controller.cpp" line="175"/>
         <source>Video not found</source>
         <translation>Videota ei löytynyt</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="193"/>
+        <location filename="../../../controller.cpp" line="230"/>
         <source>Copied to clipboard</source>
         <translation>Kopioitu leikepöydälle</translation>
     </message>
@@ -532,194 +536,214 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
         <source>Mobile</source>
         <translation>Mobiili</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
         <source>High Quality</source>
         <translation>Korkea laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
-        <location filename="../SettingsDialog.qml" line="36"/>
-        <location filename="../SettingsDialog.qml" line="62"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <location filename="../SettingsDialog.qml" line="71"/>
         <source>Automatically</source>
         <translation>Automaattisesti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
-        <location filename="../SettingsDialog.qml" line="39"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Manually</source>
         <translation>Manuaalisesti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="77"/>
+        <source>On</source>
+        <translation>On</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="48"/>
+        <source>Off</source>
+        <translation>Pois</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Automatic</source>
         <translation>Automaattinen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Landscape</source>
         <translation>Vaaka</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Portrait</source>
         <translation>Pysty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="430"/>
         <source>Media Player</source>
         <translation>Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="23"/>
         <source>Light</source>
         <translation>Vaalea</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="23"/>
         <source>Dark</source>
         <translation>Tumma</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>English</source>
         <translation>Englanti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>German</source>
         <translation>Saksa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>Finnish</source>
         <translation>Suomi</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>Italian</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="35"/>
-        <location filename="../SettingsDialog.qml" line="63"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Queued</source>
         <translation>Jonossa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="66"/>
+        <location filename="../SettingsDialog.qml" line="75"/>
         <source>Paused</source>
         <translation>Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="69"/>
+        <location filename="../SettingsDialog.qml" line="84"/>
         <source>Your settings have been saved</source>
         <translation>Asetukset tallennettu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="74"/>
-        <location filename="../SettingsDialog.qml" line="104"/>
+        <location filename="../SettingsDialog.qml" line="89"/>
+        <location filename="../SettingsDialog.qml" line="119"/>
         <source>Download Path</source>
         <translation>Latauspolku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="76"/>
+        <location filename="../SettingsDialog.qml" line="91"/>
         <source>Download Location</source>
         <translation>Lataussijainti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="95"/>
-        <location filename="../SettingsDialog.qml" line="294"/>
+        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Playback Quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="98"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Download Quality</source>
         <translation>Latauksen laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="101"/>
-        <location filename="../SettingsDialog.qml" line="330"/>
+        <location filename="../SettingsDialog.qml" line="116"/>
+        <location filename="../SettingsDialog.qml" line="356"/>
         <source>Start Downloads</source>
         <translation>Käynnistä lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
-        <location filename="../SettingsDialog.qml" line="368"/>
+        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="261"/>
+        <location filename="../SettingsDialog.qml" line="394"/>
+        <source>Safe Search</source>
+        <translation>Turvallinen Haku</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Screen Orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="113"/>
-        <location filename="../SettingsDialog.qml" line="259"/>
-        <location filename="../SettingsDialog.qml" line="404"/>
+        <location filename="../SettingsDialog.qml" line="131"/>
+        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="448"/>
         <source>Theme</source>
         <translation>Teema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="116"/>
-        <location filename="../SettingsDialog.qml" line="268"/>
-        <location filename="../SettingsDialog.qml" line="422"/>
+        <location filename="../SettingsDialog.qml" line="134"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
+        <location filename="../SettingsDialog.qml" line="466"/>
         <source>Language</source>
         <translation>Kieli</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="143"/>
         <source>Your saved searches have been cleared</source>
         <translation>Tallennetut hakusanat on tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="146"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Tietokantavirhe. Hakuja ei tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="211"/>
+        <location filename="../SettingsDialog.qml" line="229"/>
         <source>Playback quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="219"/>
+        <location filename="../SettingsDialog.qml" line="237"/>
         <source>Download quality</source>
         <translation>Latauksien laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="227"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Start downloads</source>
         <translation>Aloita lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="235"/>
+        <location filename="../SettingsDialog.qml" line="253"/>
         <source>Download location</source>
         <translation>Latauskansio</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="243"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Screen orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="251"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Media player</source>
         <translation>Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="436"/>
+        <location filename="../SettingsDialog.qml" line="480"/>
         <source>Clear saved searches</source>
         <translation>Tyhjennä hakusanat</translation>
     </message>
@@ -1065,6 +1089,12 @@
         <source>By </source>
         <translation>Kirjoittaja: </translation>
     </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="442"/>
+        <location filename="../VideoInfoView.qml" line="445"/>
+        <source> on </source>
+        <translation> milloin: </translation>
+    </message>
     <message>
         <location filename="../VideoInfoView.qml" line="511"/>
         <source>Views</source>
@@ -1163,108 +1193,93 @@
 <context>
     <name>Widget</name>
     <message>
-        <location filename="../Widget.qml" line="81"/>
         <source>Error: Unable to retrieve video</source>
-        <translation>Virhe: videon lataus epäonnistui</translation>
+        <translation type="obsolete">Virhe: videon lataus epäonnistui</translation>
+    </message>
+    <message>
+        <location filename="../Widget.qml" line="271"/>
+        <source>No videos found</source>
+        <translation>Ei videoita</translation>
     </message>
 </context>
 <context>
     <name>XHamsterInfoView</name>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="211"/>
         <source>Info</source>
-        <translation>Tietoa</translation>
+        <translation type="obsolete">Tietoa</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="250"/>
         <source>Related</source>
-        <translation>Liittyvät</translation>
+        <translation type="obsolete">Liittyvät</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="332"/>
-        <location filename="../XHamsterInfoView.qml" line="335"/>
         <source>By </source>
-        <translation>Kirjoittaja: </translation>
+        <translation type="obsolete">Kirjoittaja: </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="334"/>
-        <location filename="../XHamsterInfoView.qml" line="337"/>
         <source> on </source>
-        <translation>milloin: </translation>
+        <translation type="obsolete">milloin: </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="353"/>
         <source>Views </source>
-        <translation>Katselut</translation>
+        <translation type="obsolete">Katselut</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="359"/>
         <source>Tags</source>
-        <translation>Tagit</translation>
+        <translation type="obsolete">Tagit</translation>
     </message>
 </context>
 <context>
     <name>XHamsterListView</name>
     <message>
-        <location filename="../XHamsterListView.qml" line="148"/>
         <source>Multi-select</source>
-        <translation>Monivalinta</translation>
+        <translation type="obsolete">Monivalinta</translation>
     </message>
     <message>
-        <location filename="../XHamsterListView.qml" line="150"/>
         <source>Download video</source>
-        <translation>Lataa video</translation>
+        <translation type="obsolete">Lataa video</translation>
     </message>
     <message>
-        <location filename="../XHamsterListView.qml" line="186"/>
         <source>No videos found</source>
-        <translation>Ei videoita</translation>
+        <translation type="obsolete">Ei videoita</translation>
     </message>
 </context>
 <context>
     <name>YouJizzInfoView</name>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="65"/>
         <source>Copy to clipboard</source>
-        <translation>Kopioi leikepöydälle</translation>
+        <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="200"/>
         <source>Info</source>
-        <translation>Tietoa</translation>
+        <translation type="obsolete">Tietoa</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="239"/>
         <source>Related</source>
-        <translation>Liittyvät</translation>
+        <translation type="obsolete">Liittyvät</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="316"/>
         <source>Views </source>
-        <translation>Katseluja</translation>
+        <translation type="obsolete">Katseluja</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="322"/>
         <source>Tags</source>
-        <translation>Tagit</translation>
+        <translation type="obsolete">Tagit</translation>
     </message>
 </context>
 <context>
     <name>YouJizzListView</name>
     <message>
-        <location filename="../YouJizzListView.qml" line="135"/>
         <source>Multi-select</source>
-        <translation>Monivalinta</translation>
+        <translation type="obsolete">Monivalinta</translation>
     </message>
     <message>
-        <location filename="../YouJizzListView.qml" line="137"/>
         <source>Download video</source>
-        <translation>Lataa video</translation>
+        <translation type="obsolete">Lataa video</translation>
     </message>
     <message>
-        <location filename="../YouJizzListView.qml" line="173"/>
         <source>No videos found</source>
-        <translation>Ei videoita</translation>
+        <translation type="obsolete">Ei videoita</translation>
     </message>
 </context>
 <context>
@@ -1285,34 +1300,34 @@
         <translation>Olet kirjautunut YouTubeen tilillä: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="115"/>
-        <location filename="../../../youtube.cpp" line="221"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
         <translation>Virhe - Palvelin vastasi: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="165"/>
-        <location filename="../../../youtube.cpp" line="173"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Lataus keskeytetty</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="180"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Lataus keskeytyi. Kokeilen jatkaa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="184"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Lataus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Lataus valmistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="383"/>
+        <location filename="../../../youtube.cpp" line="387"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Virhe: videon lataus epäonnistui</translation>
     </message>
@@ -1321,12 +1336,16 @@
     <name>main</name>
     <message>
         <location filename="../main.qml" line="18"/>
+        <source>Dark</source>
+        <translation>Tumma</translation>
+    </message>
+    <message>
         <location filename="../main.qml" line="21"/>
         <location filename="../main.qml" line="22"/>
         <location filename="../main.qml" line="23"/>
         <location filename="../main.qml" line="24"/>
-        <source>Dark</source>
-        <translation>Tumma</translation>
+        <source>Light</source>
+        <translation>Vaalea</translation>
     </message>
     <message>
         <location filename="../main.qml" line="109"/>
@@ -1454,7 +1473,7 @@
         <translation>arvio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="237"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Search </source>
         <translation>Haku</translation>
     </message>
@@ -1473,27 +1492,27 @@
         <translation>Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="130"/>
+        <location filename="../scripts/settings.js" line="131"/>
         <source>Automatic</source>
         <translation>Automaattinen</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="131"/>
+        <location filename="../scripts/settings.js" line="132"/>
         <source>Media Player</source>
         <translation>Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="132"/>
+        <location filename="../scripts/settings.js" line="133"/>
         <source>Date</source>
         <translation>Pvm</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="133"/>
+        <location filename="../scripts/settings.js" line="134"/>
         <source>Dark</source>
         <translation>Tumma</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="134"/>
+        <location filename="../scripts/settings.js" line="135"/>
         <source>English</source>
         <translation>Englanti</translation>
     </message>
@@ -1501,37 +1520,28 @@
 <context>
     <name>xtube</name>
     <message>
-        <location filename="../scripts/xtube.js" line="7"/>
-        <location filename="../scripts/xtube.js" line="57"/>
         <source>date</source>
-        <translation>pvm</translation>
+        <translation type="obsolete">pvm</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="10"/>
         <source>views</source>
-        <translation>katselut</translation>
+        <translation type="obsolete">katselut</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="13"/>
         <source>rating</source>
-        <translation>arvio</translation>
+        <translation type="obsolete">arvio</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="18"/>
-        <location filename="../scripts/xtube.js" line="62"/>
         <source>Search </source>
-        <translation>Haku</translation>
+        <translation type="obsolete">Haku</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="39"/>
-        <location filename="../scripts/xtube.js" line="82"/>
         <source>Video Info</source>
-        <translation>Videon tiedot</translation>
+        <translation type="obsolete">Videon tiedot</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="57"/>
         <source>relevance</source>
-        <translation>liittyvät</translation>
+        <translation type="obsolete">liittyvät</translation>
     </message>
 </context>
 </TS>
