@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.5.1</source>
+        <source>cuteTube-QML - 0.6.1</source>
         <translation></translation>
     </message>
     <message>
@@ -179,30 +179,30 @@
     <message>
         <location filename="../../../controller.cpp" line="47"/>
         <source>Italian</source>
-        <translation>Italiano</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../controller.cpp" line="48"/>
         <source>Finnish</source>
-        <translation>Finlandese</translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="131"/>
+        <location filename="../../../controller.cpp" line="168"/>
         <source>Video deleted from device</source>
         <translation>Video cancellato dal dispositivo</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="134"/>
+        <location filename="../../../controller.cpp" line="171"/>
         <source>Unable to delete video</source>
         <translation>Impossibile cancellare il video</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="138"/>
+        <location filename="../../../controller.cpp" line="175"/>
         <source>Video not found</source>
         <translation>Video non trovato</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="193"/>
+        <location filename="../../../controller.cpp" line="230"/>
         <source>Copied to clipboard</source>
         <translation>Copiato negli appunti</translation>
     </message>
@@ -439,7 +439,7 @@
     <message>
         <location filename="../PlaylistDelegate.qml" line="31"/>
         <source> videos</source>
-        <translation>video</translation>
+        <translation> video</translation>
     </message>
 </context>
 <context>
@@ -532,194 +532,214 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
         <source>Mobile</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
         <source>High Quality</source>
         <translation>Alta Qualità</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
-        <location filename="../SettingsDialog.qml" line="36"/>
-        <location filename="../SettingsDialog.qml" line="62"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <location filename="../SettingsDialog.qml" line="71"/>
         <source>Automatically</source>
         <translation>Automaticamente</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
-        <location filename="../SettingsDialog.qml" line="39"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Manually</source>
         <translation>Manualmente</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="77"/>
+        <source>On</source>
+        <translation>Su</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="48"/>
+        <source>Off</source>
+        <translation>Off</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Automatic</source>
         <translation>Automatico</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Landscape</source>
         <translation>Orizzontale</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Portrait</source>
         <translation>Verticale</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="430"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="23"/>
         <source>Light</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="23"/>
         <source>Dark</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>English</source>
         <translation>Inglese</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>German</source>
         <translation>Tedesco</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>Finnish</source>
-        <translation>Finlandese</translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>Italian</source>
-        <translation>Italiano</translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="35"/>
-        <location filename="../SettingsDialog.qml" line="63"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Queued</source>
         <translation>In Coda</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="66"/>
+        <location filename="../SettingsDialog.qml" line="75"/>
         <source>Paused</source>
         <translation>In Pausa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="69"/>
+        <location filename="../SettingsDialog.qml" line="84"/>
         <source>Your settings have been saved</source>
         <translation>Le tue impostazioni sono state salvate</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="74"/>
-        <location filename="../SettingsDialog.qml" line="104"/>
+        <location filename="../SettingsDialog.qml" line="89"/>
+        <location filename="../SettingsDialog.qml" line="119"/>
         <source>Download Path</source>
         <translation>Percorso Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="76"/>
+        <location filename="../SettingsDialog.qml" line="91"/>
         <source>Download Location</source>
         <translation>Destinazione Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="95"/>
-        <location filename="../SettingsDialog.qml" line="294"/>
+        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Playback Quality</source>
         <translation>Qualità Riproduzione</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="98"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Download Quality</source>
         <translation>Qualità Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="101"/>
-        <location filename="../SettingsDialog.qml" line="330"/>
+        <location filename="../SettingsDialog.qml" line="116"/>
+        <location filename="../SettingsDialog.qml" line="356"/>
         <source>Start Downloads</source>
         <translation>Inizia Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
-        <location filename="../SettingsDialog.qml" line="368"/>
+        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="261"/>
+        <location filename="../SettingsDialog.qml" line="394"/>
+        <source>Safe Search</source>
+        <translation>Ricerca Sicura</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Screen Orientation</source>
         <translation>Orientamento Schermo</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="113"/>
-        <location filename="../SettingsDialog.qml" line="259"/>
-        <location filename="../SettingsDialog.qml" line="404"/>
+        <location filename="../SettingsDialog.qml" line="131"/>
+        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="448"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="116"/>
-        <location filename="../SettingsDialog.qml" line="268"/>
-        <location filename="../SettingsDialog.qml" line="422"/>
+        <location filename="../SettingsDialog.qml" line="134"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
+        <location filename="../SettingsDialog.qml" line="466"/>
         <source>Language</source>
         <translation>Lingua</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="143"/>
         <source>Your saved searches have been cleared</source>
         <translation>Le tue ricerche salvate sono state cancellate</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="146"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Errore database. Impossibile cancellare le ricerche</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Settings</source>
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="211"/>
+        <location filename="../SettingsDialog.qml" line="229"/>
         <source>Playback quality</source>
         <translation>Qualità riproduzione</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="219"/>
+        <location filename="../SettingsDialog.qml" line="237"/>
         <source>Download quality</source>
         <translation>Qualità download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="227"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Start downloads</source>
         <translation>Inizia download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="235"/>
+        <location filename="../SettingsDialog.qml" line="253"/>
         <source>Download location</source>
         <translation>Destinazione download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="243"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Screen orientation</source>
         <translation>Orientamento schermo</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="251"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="436"/>
+        <location filename="../SettingsDialog.qml" line="480"/>
         <source>Clear saved searches</source>
         <translation>Cancella ricerche salvate</translation>
     </message>
@@ -729,7 +749,7 @@
     <message>
         <location filename="../../../sharing.cpp" line="78"/>
         <source>Error - Server repsonse is: </source>
-        <translation>Errore - Il server ha risposto:</translation>
+        <translation>Errore - Il server ha risposto: </translation>
     </message>
 </context>
 <context>
@@ -1065,6 +1085,12 @@
         <source>By </source>
         <translation>Da </translation>
     </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="442"/>
+        <location filename="../VideoInfoView.qml" line="445"/>
+        <source> on </source>
+        <translation> il </translation>
+    </message>
     <message>
         <location filename="../VideoInfoView.qml" line="511"/>
         <source>Views</source>
@@ -1088,7 +1114,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="611"/>
         <source> comments</source>
-        <translation>commenti</translation>
+        <translation> commenti</translation>
     </message>
     <message>
         <location filename="../VideoInfoView.qml" line="704"/>
@@ -1163,108 +1189,65 @@
 <context>
     <name>Widget</name>
     <message>
-        <location filename="../Widget.qml" line="81"/>
-        <source>Error: Unable to retrieve video</source>
-        <translation>Errore: Impossibile recuperare il video</translation>
+        <location filename="../Widget.qml" line="271"/>
+        <source>No videos found</source>
+        <translation>Nessun video trovato</translation>
     </message>
 </context>
 <context>
     <name>XHamsterInfoView</name>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="211"/>
-        <source>Info</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="250"/>
         <source>Related</source>
-        <translation>Correlati</translation>
+        <translation type="obsolete">Correlati</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="332"/>
-        <location filename="../XHamsterInfoView.qml" line="335"/>
         <source>By </source>
-        <translation>Da </translation>
+        <translation type="obsolete">Da </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="334"/>
-        <location filename="../XHamsterInfoView.qml" line="337"/>
         <source> on </source>
-        <translation> il </translation>
+        <translation type="obsolete"> il </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="353"/>
         <source>Views </source>
-        <translation>Visualizzazioni</translation>
-    </message>
-    <message>
-        <location filename="../XHamsterInfoView.qml" line="359"/>
-        <source>Tags</source>
-        <translation></translation>
+        <translation type="obsolete">Visualizzazioni</translation>
     </message>
 </context>
 <context>
     <name>XHamsterListView</name>
     <message>
-        <location filename="../XHamsterListView.qml" line="148"/>
-        <source>Multi-select</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../XHamsterListView.qml" line="150"/>
         <source>Download video</source>
-        <translation>Scarica video</translation>
+        <translation type="obsolete">Scarica video</translation>
     </message>
     <message>
-        <location filename="../XHamsterListView.qml" line="186"/>
         <source>No videos found</source>
-        <translation>Nessun video trovato</translation>
+        <translation type="obsolete">Nessun video trovato</translation>
     </message>
 </context>
 <context>
     <name>YouJizzInfoView</name>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="65"/>
         <source>Copy to clipboard</source>
-        <translation>Copia negli appunti</translation>
+        <translation type="obsolete">Copia negli appunti</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="200"/>
-        <source>Info</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzInfoView.qml" line="239"/>
         <source>Related</source>
-        <translation>Correlati</translation>
+        <translation type="obsolete">Correlati</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="316"/>
         <source>Views </source>
-        <translation>Visualizzazioni</translation>
-    </message>
-    <message>
-        <location filename="../YouJizzInfoView.qml" line="322"/>
-        <source>Tags</source>
-        <translation></translation>
+        <translation type="obsolete">Visualizzazioni</translation>
     </message>
 </context>
 <context>
     <name>YouJizzListView</name>
     <message>
-        <location filename="../YouJizzListView.qml" line="135"/>
-        <source>Multi-select</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../YouJizzListView.qml" line="137"/>
         <source>Download video</source>
-        <translation>Scarica video</translation>
+        <translation type="obsolete">Scarica video</translation>
     </message>
     <message>
-        <location filename="../YouJizzListView.qml" line="173"/>
         <source>No videos found</source>
-        <translation>Nessun video trovato</translation>
+        <translation type="obsolete">Nessun video trovato</translation>
     </message>
 </context>
 <context>
@@ -1285,34 +1268,34 @@
         <translation>Hai effettuato l&apos;accesso a YouTube come &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="115"/>
-        <location filename="../../../youtube.cpp" line="221"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
-        <translation>Errore - Il server ha risposto:</translation>
+        <translation>Errore - Il server ha risposto: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="165"/>
-        <location filename="../../../youtube.cpp" line="173"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Caricamento interrotto</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="180"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Caricamento interrotto. Tenetativo di ripresa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="184"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Caricamento fallito</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Caricamento completato</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="383"/>
+        <location filename="../../../youtube.cpp" line="387"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Errore: Impossibile recuperare il video</translation>
     </message>
@@ -1321,12 +1304,16 @@
     <name>main</name>
     <message>
         <location filename="../main.qml" line="18"/>
+        <source>Dark</source>
+        <translation></translation>
+    </message>
+    <message>
         <location filename="../main.qml" line="21"/>
         <location filename="../main.qml" line="22"/>
         <location filename="../main.qml" line="23"/>
         <location filename="../main.qml" line="24"/>
-        <source>Dark</source>
-        <translation></translation>
+        <source>Light</source>
+        <translation>Luce</translation>
     </message>
     <message>
         <location filename="../main.qml" line="109"/>
@@ -1454,9 +1441,9 @@
         <translation>voto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="237"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Search </source>
-        <translation>Cerca</translation>
+        <translation>Cerca </translation>
     </message>
 </context>
 <context>
@@ -1473,27 +1460,27 @@
         <translation>In Pausa</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="130"/>
+        <location filename="../scripts/settings.js" line="131"/>
         <source>Automatic</source>
         <translation>Automatico</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="131"/>
+        <location filename="../scripts/settings.js" line="132"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="132"/>
+        <location filename="../scripts/settings.js" line="133"/>
         <source>Date</source>
         <translation>Data</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="133"/>
+        <location filename="../scripts/settings.js" line="134"/>
         <source>Dark</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="134"/>
+        <location filename="../scripts/settings.js" line="135"/>
         <source>English</source>
         <translation>Inglese</translation>
     </message>
@@ -1501,37 +1488,28 @@
 <context>
     <name>xtube</name>
     <message>
-        <location filename="../scripts/xtube.js" line="7"/>
-        <location filename="../scripts/xtube.js" line="57"/>
         <source>date</source>
-        <translation>data</translation>
+        <translation type="obsolete">data</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="10"/>
         <source>views</source>
-        <translation>visualizzazioni</translation>
+        <translation type="obsolete">visualizzazioni</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="13"/>
         <source>rating</source>
-        <translation>voto</translation>
+        <translation type="obsolete">voto</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="18"/>
-        <location filename="../scripts/xtube.js" line="62"/>
         <source>Search </source>
-        <translation>Cerca</translation>
+        <translation type="obsolete">Cerca </translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="39"/>
-        <location filename="../scripts/xtube.js" line="82"/>
         <source>Video Info</source>
-        <translation>Info Video</translation>
+        <translation type="obsolete">Info Video</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="57"/>
         <source>relevance</source>
-        <translation>pertinenza</translation>
+        <translation type="obsolete">pertinenza</translation>
     </message>
 </context>
 </TS>
