@@ -232,7 +232,9 @@ function youtubeSearch(query, order) {
         searchOrder = "rating";
     }
 
-    var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
+    var safe = Settings.getSetting("safeSearch");
+
+    var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=" + safe + "&q="
                      + encodeURIComponent(query).replace(" ", "+") + "&orderby=" + searchOrder);
     loadVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
