@@ -65,6 +65,11 @@ void YouTube::setAccessToken(const QByteArray &token) {
     emit accessTokenChanged();
 }
 
+void YouTube::printAccessToken() {
+    printf(accessToken.toAscii());
+    emit tokenPrinted();
+}
+
 void YouTube::uploadVideo(const QString &filename, const QString &title, const QString &description, const QString &tags, const QString &category, const bool &isPrivate) {
 
     fileToBeUploaded = new QFile(filename);
