@@ -28,6 +28,7 @@ public:
 
 public slots:
     void login(const QString &username, const QString &password);
+    void printAccessToken();
     void addToFavourites(const QString &videoId);
     void deleteFromFavourites(const QString &favouriteId);
     void addToPlaylist(const QString &videoId, const QString &playlistId);
@@ -77,6 +78,7 @@ signals:
     void alert(const QString &message);
     void currentUserChanged();
     void accessTokenChanged();
+    void tokenPrinted();
     void postSuccessful();
     void addedToFavourites();
     void addedToPlaylist();
